@@ -41,6 +41,9 @@
 
 #ifdef Q_OS_LINUX
 #include <sys/sysinfo.h>
+#elif defined(Q_OS_FREEBSD)
+#include <sys/types.h>
+#include <sys/sysctl.h>
 #endif
 #include <sys/utsname.h>
 
@@ -55,6 +58,15 @@ static qlonglong calculateTotalRam()
     if (sysinfo(&info) == 0)
         // manpage "sizes are given as multiples of mem_unit bytes"
         ret = info.totalram * info.mem_unit;
+#elif defined(Q_OS_FREEBSD)
+    /* Stuff for sysctl */
+    size_t len;
+
+    unsigned long memory;
+    len = sizeof(memory);
+    sysctlbyname("hw.physmem", &memory, &len, NULL, 0);
+
+    ret = memory;
 #endif
     return ret;
 }
@@ -83,6 +95,11 @@ Module::Module(QWidget *parent, const QVariantList &args) :
     font.setBold(true);
     ui->nameVersionLabel->setFont(font);
 
+    QFont fontVariant = ui->variantLabel->font();
+    fontVariant.setPixelSize(18);
+    fontVariant.setBold(true);
+    ui->variantLabel->setFont(fontVariant);
+
     ui->urlLabel->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::LinksAccessibleByMouse);
 
     // We have no help so remove the button from the buttons.
@@ -104,10 +121,11 @@ void Module::load()
 
     QString logoPath = cg.readEntry("LogoPath", QString());
     QPixmap logo;
-    if (logoPath.isEmpty())
+    if (logoPath.isEmpty()) {
         logo = QIcon::fromTheme(QStringLiteral("start-here-kde")).pixmap(128, 128);
-    else
+    } else {
         logo = QPixmap(logoPath);
+    }
     ui->logoLabel->setPixmap(logo);
 
     OSRelease os;
@@ -115,13 +133,22 @@ void Module::load()
     // For example OS Ubuntu may be rebranded as Kubuntu. Also Kubuntu Active
     // as a product brand is different from Kubuntu.
     QString distroName = cg.readEntry("Name", os.name);
-    ui->nameVersionLabel->setText(QStringLiteral("%1 %2").arg(distroName, os.versionId));
+    QString versionId = cg.readEntry("Version", os.versionId);
+    ui->nameVersionLabel->setText(QStringLiteral("%1 %2").arg(distroName, versionId));
+
+    QString variant = cg.readEntry("Variant", QString());
+    if (variant.isEmpty()) {
+        ui->variantLabel->hide();
+    } else {
+        ui->variantLabel->setText(variant);
+    }
 
     QString url = cg.readEntry("Website", os.homeUrl);
-    if (url.isEmpty())
+    if (url.isEmpty()) {
         ui->urlLabel->hide();
-    else
+    } else {
         ui->urlLabel->setText(QStringLiteral("<a href='%1'>%1</a>").arg(url));
+    }
 
     // Since Plasma version detection isn't based on a library query it can fail
     // in weird cases; instead of admiting defeat we simply hide everything :P
@@ -147,8 +174,9 @@ void Module::load()
     if(uname(&utsName) != 0) {
         ui->kernel->hide();
         ui->kernelLabel->hide();
-    } else
+    } else {
         ui->kernelLabel->setText(utsName.release);
+    }
 
     const int bits = QT_POINTER_SIZE == 8 ? 64 : 32;
     ui->bitsLabel->setText(i18nc("@label %1 is the CPU bit width (e.g. 32 or 64)",
